# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.user_file_share_access_info_status import UserFileShareAccessInfoStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestUserFileShareAccessInfoStatus(unittest.TestCase):
    """UserFileShareAccessInfoStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserFileShareAccessInfoStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.user_file_share_access_info_status.UserFileShareAccessInfoStatus()  # noqa: E501
        if include_optional :
            return UserFileShareAccessInfoStatus(
                user_id = 'tuU7smH86zAXMl76sua6xQ', 
                org_id = 'IAsl3dl40aSsfLKiU76', 
                org_name = 'egov', 
                parent_org_id = 'G99q3lasls29wsk', 
                parent_org_name = 'root', 
                share_id = '123', 
                share_name = 'public', 
                share_url = 'https://files.cloud.egov.city/public', 
                access_level = 'requested', 
                roles = [
                    '0'
                    ]
            )
        else :
            return UserFileShareAccessInfoStatus(
                user_id = 'tuU7smH86zAXMl76sua6xQ',
                org_id = 'IAsl3dl40aSsfLKiU76',
                org_name = 'egov',
                share_id = '123',
                share_name = 'public',
                share_url = 'https://files.cloud.egov.city/public',
                access_level = 'requested',
        )

    def testUserFileShareAccessInfoStatus(self):
        """Test UserFileShareAccessInfoStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
