# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CombinedRulesStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_id': 'str',
        'org_id': 'str',
        'role_id': 'str',
        'role_name': 'str',
        'rules': 'list[RuleV2]',
        'scope': 'RuleScopeEnum'
    }

    attribute_map = {
        'app_id': 'app_id',
        'org_id': 'org_id',
        'role_id': 'role_id',
        'role_name': 'role_name',
        'rules': 'rules',
        'scope': 'scope'
    }

    def __init__(self, app_id=None, org_id=None, role_id=None, role_name=None, rules=None, scope=None, local_vars_configuration=None):  # noqa: E501
        """CombinedRulesStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._app_id = None
        self._org_id = None
        self._role_id = None
        self._role_name = None
        self._rules = None
        self._scope = None
        self.discriminator = None

        if app_id is not None:
            self.app_id = app_id
        if org_id is not None:
            self.org_id = org_id
        if role_id is not None:
            self.role_id = role_id
        if role_name is not None:
            self.role_name = role_name
        if rules is not None:
            self.rules = rules
        if scope is not None:
            self.scope = scope

    @property
    def app_id(self):
        """Gets the app_id of this CombinedRulesStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The app_id of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this CombinedRulesStatus.

        Unique identifier  # noqa: E501

        :param app_id: The app_id of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def org_id(self):
        """Gets the org_id of this CombinedRulesStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this CombinedRulesStatus.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def role_id(self):
        """Gets the role_id of this CombinedRulesStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The role_id of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this CombinedRulesStatus.

        Unique identifier  # noqa: E501

        :param role_id: The role_id of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._role_id = role_id

    @property
    def role_name(self):
        """Gets the role_name of this CombinedRulesStatus.  # noqa: E501

        The name of the role under which these rules were combined. If no role was associated with the rules, will be empty.   # noqa: E501

        :return: The role_name of this CombinedRulesStatus.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this CombinedRulesStatus.

        The name of the role under which these rules were combined. If no role was associated with the rules, will be empty.   # noqa: E501

        :param role_name: The role_name of this CombinedRulesStatus.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def rules(self):
        """Gets the rules of this CombinedRulesStatus.  # noqa: E501

        The rules combined together by the common property indicated by scope or role_id   # noqa: E501

        :return: The rules of this CombinedRulesStatus.  # noqa: E501
        :rtype: list[RuleV2]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this CombinedRulesStatus.

        The rules combined together by the common property indicated by scope or role_id   # noqa: E501

        :param rules: The rules of this CombinedRulesStatus.  # noqa: E501
        :type: list[RuleV2]
        """

        self._rules = rules

    @property
    def scope(self):
        """Gets the scope of this CombinedRulesStatus.  # noqa: E501


        :return: The scope of this CombinedRulesStatus.  # noqa: E501
        :rtype: RuleScopeEnum
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this CombinedRulesStatus.


        :param scope: The scope of this CombinedRulesStatus.  # noqa: E501
        :type: RuleScopeEnum
        """

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CombinedRulesStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CombinedRulesStatus):
            return True

        return self.to_dict() != other.to_dict()
