# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_per_share_stats import AgentConnectorPerShareStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorPerShareStats(unittest.TestCase):
    """AgentConnectorPerShareStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorPerShareStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_per_share_stats.AgentConnectorPerShareStats()  # noqa: E501
        if include_optional :
            return AgentConnectorPerShareStats(
                share_prefix = '/public', 
                share_id = '5s930sdfsdlA', 
                local_path = '/home/user/shared', 
                total_requests = 5132, 
                successful_requests = 5102, 
                failed_requests = 30, 
                bytes_sent = 30458101, 
                bytes_received = 9574339, 
                share_start_time = '2020-07-07T15:55:52.230Z'
            )
        else :
            return AgentConnectorPerShareStats(
                share_prefix = '/public',
                share_id = '5s930sdfsdlA',
                local_path = '/home/user/shared',
                total_requests = 5132,
                successful_requests = 5102,
                failed_requests = 30,
                bytes_sent = 30458101,
                bytes_received = 9574339,
                share_start_time = '2020-07-07T15:55:52.230Z',
        )

    def testAgentConnectorPerShareStats(self):
        """Test AgentConnectorPerShareStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
