# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.web_auth_n_enrollment_spec import WebAuthNEnrollmentSpec  # noqa: E501
from agilicus_api.rest import ApiException

class TestWebAuthNEnrollmentSpec(unittest.TestCase):
    """WebAuthNEnrollmentSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebAuthNEnrollmentSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.web_auth_n_enrollment_spec.WebAuthNEnrollmentSpec()  # noqa: E501
        if include_optional :
            return WebAuthNEnrollmentSpec(
                user_id = '123', 
                relying_party_id = '123', 
                attestation_format = 'platform', 
                attestation_conveyance = 'direct', 
                user_verification = 'discouraged'
            )
        else :
            return WebAuthNEnrollmentSpec(
                user_id = '123',
                relying_party_id = '123',
        )

    def testWebAuthNEnrollmentSpec(self):
        """Test WebAuthNEnrollmentSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
