# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.resources_api import ResourcesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestResourcesApi(unittest.TestCase):
    """ResourcesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.resources_api.ResourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list_resources(self):
        """Test case for list_resources

        List all Resources  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
