# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.08
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_cert_signing_req_response import ListCertSigningReqResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListCertSigningReqResponse(unittest.TestCase):
    """ListCertSigningReqResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListCertSigningReqResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_cert_signing_req_response.ListCertSigningReqResponse()  # noqa: E501
        if include_optional :
            return ListCertSigningReqResponse(
                certificate_signing_requests = [
                    agilicus_api.models.cert_signing_req.CertSigningReq(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.cert_signing_req_spec.CertSigningReqSpec(
                            org_id = '123', 
                            auto_renew = True, 
                            rotate_keys = True, 
                            request = '0', ), 
                        status = agilicus_api.models.cert_signing_req_status.CertSigningReqStatus(
                            certificates = [
                                agilicus_api.models.x509_certificate.X509Certificate(
                                    spec = agilicus_api.models.x509_certificate_spec.X509CertificateSpec(
                                        certificate = '0', 
                                        csr_id = '0', 
                                        org_id = '123', 
                                        message = '0', 
                                        reason = 'pending', ), )
                                ], 
                            common_name = '0', 
                            dns_names = [
                                'a'
                                ], ), )
                    ], 
                limit = 56
            )
        else :
            return ListCertSigningReqResponse(
                certificate_signing_requests = [
                    agilicus_api.models.cert_signing_req.CertSigningReq(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.cert_signing_req_spec.CertSigningReqSpec(
                            org_id = '123', 
                            auto_renew = True, 
                            rotate_keys = True, 
                            request = '0', ), 
                        status = agilicus_api.models.cert_signing_req_status.CertSigningReqStatus(
                            certificates = [
                                agilicus_api.models.x509_certificate.X509Certificate(
                                    spec = agilicus_api.models.x509_certificate_spec.X509CertificateSpec(
                                        certificate = '0', 
                                        csr_id = '0', 
                                        org_id = '123', 
                                        message = '0', 
                                        reason = 'pending', ), )
                                ], 
                            common_name = '0', 
                            dns_names = [
                                'a'
                                ], ), )
                    ],
                limit = 56,
        )

    def testListCertSigningReqResponse(self):
        """Test ListCertSigningReqResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
